# ConSys [![Build Status](https://app.travis-ci.com/kosyachniy/consys.svg?branch=main)](https://app.travis-ci.com/kosyachniy/consys)
Object-oriented programming control system in Python [Base Object Model]

[GitHub](https://github.com/kosyachniy/consys)
 | [PyPI](https://pypi.org/project/consys/)

[View ORM for PostgreSQL →](https://pypi.org/project/consql/)

## Submodules
Module | Description
---|----
` consys ` | ORM for Python & MongoDB
` consys.handlers ` | Ready to use handlers for ORM
` consys.files ` | File uploading system
` consys.types ` | Type checking system
` consys.errors ` | Set of errors
